.. meta::
    :description lang=en:
        Word count on an absolute and a weighted basis. An important starting
        point in text analysis and mining for any text list that comes with
        descriptive stats (pageviews, sales, bounces, sessions, etc).

.. automodule:: advertools.word_frequency
   :members:
   :undoc-members:
   :show-inheritance:
